from django import template
from django.template import Context
from django.template.loader import get_template


register = template.Library()


@register.filter
def as_bootstrap(form):
    template = get_template('bootstrap_form/form.html')

    c = Context({
        'form': form
    })

    return template.render(c)


@register.filter
def klass(ob):
    return ob.__class__.__name__.lower()



#!/usr/bin/env python

from setuptools import setup

setup(
    name='django-twitter-bootstrap-form',
    version='0.1.0',
    description='Twitter Bootstrap Form',
    author='Pragmatic Mates',
    author_email='info@pragmaticmates.com',
    maintainer='Pragmatic Mates',
    maintainer_email='info@pragmaticmates.com',
    url='https://github.com/PragmaticMates/django-twitter-bootstrap-form',
    packages=[
        'twitter_bootstrap_form',
        'twitter_bootstrap_form.templatetags'
    ],
    include_package_data=True,
    install_requires=('django'),
    classifiers=[
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.5',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Operating System :: OS Independent',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Framework :: Django',
        'License :: OSI Approved :: BSD License'],
    license='BSD License')
